@@ -336,7 +336,7 @@ return; // remove this and the above when the sound below is working correctly
 
 bool KAstTopLevel::eventFilter( QObject* /* object */, QEvent *event )
 {
-	QKeyEvent *e = dynamic_cast<QKeyEvent*>(event);
+	QKeyEvent *e = static_cast<QKeyEvent*>(event);
 	if (event->type() == QEvent::AccelOverride)
 	{
 		if (processKeyPress(e)) return true;
