@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -44,7 +44,9 @@
 #define WALL_DELAY 100
 
 
+#if HAVE_ARTS
 SimpleSoundServer *JezzGame::m_artsServer = 0;
+#endif
 QString JezzGame::m_soundPath;
 bool JezzGame::m_sound = true;
 
@@ -234,7 +236,7 @@ void Wall::fill( bool black )
 
 /*************************************************************************/
 
-JezzField::JezzField( QPixmap tiles, QPixmap background, QObject* parent, const char* name )
+JezzField::JezzField( const QPixmap &tiles, const QPixmap &background, QObject* parent, const char* name )
     : QCanvas( parent, name ), m_tiles( tiles )
 {
     setPixmaps( tiles, background );
@@ -248,7 +250,7 @@ void JezzField::setGameTile( int x, int y, bool black )
         setTile( x, y, black ? TILE_BORDER : TILE_FREE );
 }
 
-void JezzField::setBackground( QPixmap background )
+void JezzField::setBackground( const QPixmap &background )
 {
     // copy current field into buffer
     int backup[FIELD_WIDTH][FIELD_HEIGHT];
@@ -285,7 +287,7 @@ void JezzField::setBackground( QPixmap background )
         setTile( x, FIELD_HEIGHT-1, TILE_BORDER );
 }
 
-void JezzField::setPixmaps( QPixmap tiles, QPixmap background )
+void JezzField::setPixmaps( const QPixmap &tiles, const QPixmap &background )
 {
     // create new tiles
     QPixmap allTiles( TILE_SIZE*(FIELD_WIDTH-2), TILE_SIZE*(FIELD_HEIGHT-1) );
@@ -296,9 +298,9 @@ void JezzField::setPixmaps( QPixmap tiles, QPixmap background )
         // handle background
         m_background = true;
         QImage img = background.convertToImage();
-        background.convertFromImage( img.smoothScale( TILE_SIZE*(FIELD_WIDTH-2),
+        QPixmap scalledBackground( img.smoothScale( TILE_SIZE*(FIELD_WIDTH-2),
                                                       TILE_SIZE*(FIELD_HEIGHT-2) ) );
-        bitBlt( &allTiles, 0, 0, &background, 0, 0, background.width(), background.height() );
+        bitBlt( &allTiles, 0, 0, &scalledBackground, 0, 0, scalledBackground.width(), scalledBackground.height() );
     }
 
     // handle default tiles
@@ -338,7 +340,7 @@ void JezzView::viewportMouseReleaseEvent( QMouseEvent *ev )
 
 /*************************************************************************/
 
-JezzGame::JezzGame( QPixmap background, int ballNum, QWidget *parent, const char *name )
+JezzGame::JezzGame( const QPixmap &background, int ballNum, QWidget *parent, const char *name )
     : QWidget( parent, name ), m_wall1( 0 ), m_wall2( 0 ),
       m_text( 0 ), m_running( false ), m_percent( 0 ), m_pictured( false )
 {
@@ -351,10 +353,12 @@ JezzGame::JezzGame( QPixmap background, int ballNum, QWidget *parent, const char
    QPixmap tiles( path + "tiles.png" );
 
    // setup arts
+#if HAVE_ARTS
    m_artsServer = new SimpleSoundServer;
    *m_artsServer = Arts::Reference("global:Arts_SimpleSoundServer");
    if ( m_artsServer->isNull() )
        kdDebug(12008) << "Can't connect to aRts sound server" << endl;
+#endif
    m_soundPath = kapp->dirs()->findResourceDir( "data", "kbounce/sounds/death.au" ) +
                  "kbounce/sounds/";
 
@@ -387,10 +391,10 @@ JezzGame::JezzGame( QPixmap background, int ballNum, QWidget *parent, const char
    {
       Ball *ball = new Ball( m_ballPixmaps, m_field );
       m_balls.append( ball );
-      ball->setVelocity( ((rand() & 1)*2-1)*2, ((rand() & 1)*2-1)*2 );
-      ball->setFrame( rand() % 25 );
-      ball->move( 4*TILE_SIZE + rand() % ( (FIELD_WIDTH-8)*TILE_SIZE ),
-                  4*TILE_SIZE + rand() % ( (FIELD_HEIGHT-8)*TILE_SIZE ) );
+      ball->setVelocity( ((kapp->random() & 1)*2-1)*2, ((kapp->random() & 1)*2-1)*2 );
+      ball->setFrame( kapp->random() % 25 );
+      ball->move( 4*TILE_SIZE + kapp->random() % ( (FIELD_WIDTH-8)*TILE_SIZE ),
+                  4*TILE_SIZE + kapp->random() % ( (FIELD_HEIGHT-8)*TILE_SIZE ) );
       ball->show();
    }
 
@@ -412,11 +416,13 @@ JezzGame::~JezzGame()
     delete m_view;
     delete m_field;
     delete m_ballPixmaps;
+#if HAVE_ARTS
     delete m_artsServer;
+#endif
 }
 
 
-void JezzGame::display( QString text, int size )
+void JezzGame::display( const QString &text, int size )
 {
     qDebug("This function \"display\" shouldn't be called!!!");
     if ( !text.isEmpty() )
@@ -440,16 +446,20 @@ void JezzGame::display( QString text, int size )
     }
 }
 
-void JezzGame::playSound( QString name )
+void JezzGame::playSound( const QString &name )
 {
+#if HAVE_ARTS
     if( !m_artsServer->isNull() && m_sound)
     {
         QString path = m_soundPath + name;
         m_artsServer->play( path.latin1() );
     }
+#else
+	return;
+#endif
 }
 
-void JezzGame::setBackground( QPixmap background )
+void JezzGame::setBackground( const QPixmap &background )
 {
     m_field->setBackground( background );
 }
