@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 **************************************************************************** */
 #ifndef KCUBEBOXWIDGET_H
@@ -107,8 +107,8 @@ public:
    */
    void checkComputerplayer(Player player);
  
-   inline void saveGame(KConfigBase *c) { saveProperties(c); };
-   inline void restoreGame(KConfigBase *c) { readProperties(c); }; 
+   inline void saveGame(KConfigBase *c) { saveProperties(c); }
+   inline void restoreGame(KConfigBase *c) { readProperties(c); } 
   
 public slots:
    /** stops all activities like getting a hint or doing a move */
@@ -177,7 +177,7 @@ private slots:
    * checks if cube at ['row','column'] is clickable by the current player.
    * if true, it increases this cube and checks the playingfield  
    */
-   bool checkClick(int row,int column);
+   bool checkClick(int row,int column,bool isClick);
 
    /** turns off blinking, if an other cube is clicked */
    void stopHint();
