@@ -1,8 +1,6 @@
 #ifndef _KINGS_H_
 #define _KINGS_H_
 
-#include "dealer.h"
-#include "card.h"
 #include "freecell.h"
 
 class Pile;
@@ -14,9 +12,11 @@ class Kings : public FreecellBase {
 
 public:
     Kings( KMainWindow* parent=0, const char* name=0);
+    virtual bool isGameLost() const;
 
 public slots:
     virtual void deal();
+    virtual void demo();
 };
 
 #endif
