@@ -102,7 +102,7 @@ pWidget::pWidget()
     }
     games->setItems(list);
 
-    KGlobal::dirs()->addResourceType("wallpaper", KStandardDirs::kde_default("data") + "kpat/backgrounds/");  
+    KGlobal::dirs()->addResourceType("wallpaper", KStandardDirs::kde_default("data") + "kpat/backgrounds/");
     KGlobal::dirs()->addResourceType("wallpaper", KStandardDirs::kde_default("data") + "ksnake/backgrounds/");
     wallpapers = new KSelectAction(i18n("&Change Background"), 0, this,
                               SLOT(changeWallpaper()),
@@ -298,13 +298,13 @@ void pWidget::newGame()
     // then ask if she wants to abort it.
     if (!dill->isGameWon() && !dill->isGameLost()
 	&& KMessageBox::warningContinueCancel(0,
-		       i18n("You are already running an unfinished game.  "
-			    "If you abort the old game to start a new one, "
-			    "the old game will be registered as a loss in "
-			    "the statistics file.\n"
-			    "What do you want to do?"),
-		       i18n("Abort Current Game?"),
-		       i18n("Abort Old Game"),
+                                     i18n("You are already running an unfinished game.  "
+                                          "If you abort the old game to start a new one, "
+                                          "the old game will be registered as a loss in "
+                                          "the statistics file.\n"
+                                          "What do you want to do?"),
+                                     i18n("Abort Current Game?"),
+                                     i18n("Abort Old Game"),
                                      "careaboutstats" )  == KMessageBox::Cancel)
         return;
 
@@ -317,8 +317,6 @@ void pWidget::newGame()
 void pWidget::restart()
 {
     statusBar()->clear();
-    dill->resetMoves();
-    slotSetMoves( 0 );
     dill->startNew();
 }
 
@@ -339,7 +337,7 @@ void pWidget::newGameType()
 {
     delete dill;
     dill = 0;
-    slotSetMoves( 0 );
+    slotUpdateMoves();
 
     uint id = games->currentItem();
     for (QValueList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin(); it != DealerInfoList::self()->games().end(); ++it) {
@@ -352,8 +350,8 @@ void pWidget::newGameType()
             connect(dill, SIGNAL(saveGame()), SLOT(saveGame()));
             connect(dill, SIGNAL(gameInfo(const QString&)),
                     SLOT(slotGameInfo(const QString &)));
-            connect(dill, SIGNAL(setMoves(int)),
-                    SLOT(slotSetMoves(int)));
+            connect(dill, SIGNAL(updateMoves()),
+                    SLOT(slotUpdateMoves()));
             dill->setGameId(id);
             dill->setupActions();
             dill->setBackgroundPixmap(background, midcolor);
@@ -377,8 +375,6 @@ void pWidget::newGameType()
     // base class constructor runs before the derived class's
     dill->takeState();
 
-    dill->resetMoves();
-
     setGameCaption();
 
     KConfig *config = kapp->config();
@@ -406,9 +402,11 @@ void pWidget::slotGameInfo(const QString &text)
     statusBar()->message(text, 3000);
 }
 
-void pWidget::slotSetMoves( int moves )
+void pWidget::slotUpdateMoves()
 {
-  statusBar()->changeItem( i18n("1 move", "%n moves", moves), 1 );
+    int moves = 0;
+    if ( dill ) moves = dill->getMoves();
+    statusBar()->changeItem( i18n("1 move", "%n moves", moves), 1 );
 }
 
 void pWidget::setBackSide(const QString &deck, const QString &cards)
@@ -473,7 +471,7 @@ void pWidget::gameLost()
     QString grpNotifMsgs = QString::fromLatin1("Notification Messages");
 
     config = KGlobal::config();
-    KConfigGroupSaver saver(config, 
+    KConfigGroupSaver saver(config,
 			    QString::fromLatin1("Notification Messages"));
     QString dontAsk = config->readEntry(dontAskAgainName).lower();
 
@@ -489,7 +487,7 @@ void pWidget::gameLost()
     if (KMessageBox::questionYesNo(this, i18n("You could not win this game, "
                                               "but there is always a second try.\nStart a new game?"),
                                    i18n("Could Not Win!"),
-                                   i18n("New Game"), 
+                                   i18n("New Game"),
 				   KStdGuiItem::cont(),
 				   dontAskAgainName) == KMessageBox::Yes) {
 
