@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <qwidget.h>
@@ -49,8 +49,10 @@ Snake::Snake(Board *b, PixServer *p, Gate g, PixMap x)
 void Snake::updateSamy()
 {
 	int x = tail();
-	while ( x > 0)
-		*list.at(x) = *list.at(--x);
+	while ( x > 0) {
+		*list.at(x) = *list.at(x-1);
+                --x;
+        }
 }
 
 void Snake::zero()
@@ -66,9 +68,7 @@ void Snake::appendSamy()
 	Samy *sam = new Samy;
 	list.append(sam);
 
-	int x = tail();
-	while ( x > 0)
-		*list.at(x) = *list.at(--x);
+        updateSamy();
 	grow--;
 }
 
